==> kmyfirewall-trinity_3.5.13.2.orig.tar.xz: kmyfirewall-trinity-3.5.13.2/kmyfirewall/ruleoptionplugins/interface_option/kmfruleoptioneditinterface.h <==
//
// C++ Interface: kmfruleoptioneditiip
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KMFRULEOPTIONEDITINTERFACE_H
#define KMFRULEOPTIONEDITINTERFACE_H

#include "../../core/kmfruleoptioneditinterface.h"

// KDE includes
#include <kparts/part.h>
#include <kparts/plugin.h>
#include <kparts/factory.h>
#include <kxmlgui.h>

class KInstance;

namespace KMF {
class IPTRule;
class KMFRuleEditorInterface;
/**
@author Christian Hubinger
*/
class KMFRuleOptionEditorInterface : public KMFRuleOptionEditInterface {
	Q_OBJECT
  TQ_OBJECT
public:
	KMFRuleOptionEditorInterface(TQObject *parent = 0, const char *name = 0);

	~KMFRuleOptionEditorInterface();
	void loadRule( IPTRule* rule );	
	TQWidget* editWidget();
	const TQString& optionEditName() const;
	const TQString& description() const;

private slots:
	void slotShowOverview();

private:
	KMFRuleEditorInterface *m_edit;
	IPTRule *m_rule;
	
};



class KMFRuleOptionEditorInterfaceFactory : public KLibFactory {
	Q_OBJECT
  TQ_OBJECT
public:
	KMFRuleOptionEditorInterfaceFactory( TQObject *parent = 0, const char *name = 0 );
	virtual ~KMFRuleOptionEditorInterfaceFactory() {
/* 		delete s_instance; */
	};
	virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0,
	                               const char* name = TQOBJECT_OBJECT_NAME_STRING,
	                               const TQStringList &args = TQStringList() );
	/*     static KInstance* instance(); */

/*private:
	static KInstance* s_instance;*/
};
}








#endif

==> kmyfirewall-trinity-14.1.0.tar.xz: kmyfirewall-trinity-14.1.0/kmyfirewall/ruleoptionplugins/interface_option/kmfruleoptioneditinterface.h <==
//
// C++ Interface: kmfruleoptioneditiip
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KMFRULEOPTIONEDITINTERFACE_H
#define KMFRULEOPTIONEDITINTERFACE_H

#include "../../core/kmfruleoptioneditinterface.h"

// KDE includes
#include <tdeparts/part.h>
#include <tdeparts/plugin.h>
#include <tdeparts/factory.h>
#include <kxmlgui.h>

class TDEInstance;

namespace KMF {
class IPTRule;
class KMFRuleEditorInterface;
/**
@author Christian Hubinger
*/
class KMFRuleOptionEditorInterface : public KMFRuleOptionEditInterface {
	Q_OBJECT
  
public:
	KMFRuleOptionEditorInterface(TQObject *parent = 0, const char *name = 0);

	~KMFRuleOptionEditorInterface();
	void loadRule( IPTRule* rule );	
	TQWidget* editWidget();
	const TQString& optionEditName() const;
	const TQString& description() const;

private slots:
	void slotShowOverview();

private:
	KMFRuleEditorInterface *m_edit;
	IPTRule *m_rule;
	
};



class KMFRuleOptionEditorInterfaceFactory : public KLibFactory {
	Q_OBJECT
  
public:
	KMFRuleOptionEditorInterfaceFactory( TQObject *parent = 0, const char *name = 0 );
	virtual ~KMFRuleOptionEditorInterfaceFactory() {
/* 		delete s_instance; */
	};
	virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0,
	                               const char* name = TQOBJECT_OBJECT_NAME_STRING,
	                               const TQStringList &args = TQStringList() );
	/*     static TDEInstance* instance(); */

/*private:
	static TDEInstance* s_instance;*/
};
}








#endif
